# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: demoparser/protobufs/steamdatagram_messages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='demoparser/protobufs/steamdatagram_messages.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n1demoparser/protobufs/steamdatagram_messages.proto\"\xeb\x02\n CMsgSteamDatagramRouterPingReply\x12\x18\n\x10\x63lient_timestamp\x18\x01 \x01(\x07\x12\"\n\x16latency_datacenter_ids\x18\x02 \x03(\x07\x42\x02\x10\x01\x12\x1b\n\x0flatency_ping_ms\x18\x03 \x03(\rB\x02\x10\x01\x12\x16\n\x0eyour_public_ip\x18\x04 \x01(\x07\x12\x13\n\x0bserver_time\x18\x05 \x01(\x07\x12\x11\n\tchallenge\x18\x06 \x01(\x06\x12\x1e\n\x16seconds_until_shutdown\x18\x07 \x01(\r\x12\x15\n\rclient_cookie\x18\x08 \x01(\x07\x12%\n\x1dscoring_penalty_relay_cluster\x18\t \x01(\r\x12*\n\x1escoring_penalty_datacenter_ids\x18\n \x03(\x07\x42\x02\x10\x01\x12\"\n\x16scoring_penalty_values\x18\x0b \x03(\rB\x02\x10\x01\"\xdc\x01\n\x1f\x43MsgSteamDatagramGameserverPing\x12\x16\n\x0e\x63lient_session\x18\x01 \x01(\r\x12\x17\n\x0f\x63lient_steam_id\x18\x02 \x01(\x06\x12\x18\n\x10\x63lient_timestamp\x18\x03 \x01(\x07\x12\x18\n\x10router_timestamp\x18\x04 \x01(\x07\x12!\n\x19router_gameserver_latency\x18\x05 \x01(\r\x12\x19\n\x11seq_number_router\x18\x06 \x01(\r\x12\x16\n\x0eseq_number_e2e\x18\x07 \x01(\r\"\x90\x03\n%CMsgSteamDatagramGameServerAuthTicket\x12\x13\n\x0btime_expiry\x18\x01 \x01(\x07\x12\x1b\n\x13\x61uthorized_steam_id\x18\x02 \x01(\x06\x12\x1c\n\x14\x61uthorized_public_ip\x18\x03 \x01(\x07\x12\x1b\n\x13gameserver_steam_id\x18\x04 \x01(\x06\x12\x19\n\x11gameserver_net_id\x18\x05 \x01(\x06\x12\x11\n\tsignature\x18\x06 \x01(\x0c\x12\x0e\n\x06\x61pp_id\x18\x07 \x01(\r\x12G\n\x0c\x65xtra_fields\x18\x08 \x03(\x0b\x32\x31.CMsgSteamDatagramGameServerAuthTicket.ExtraField\x1as\n\nExtraField\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cstring_value\x18\x02 \x01(\t\x12\x13\n\x0bint32_value\x18\x03 \x01(\x11\x12\x15\n\rfixed32_value\x18\x04 \x01(\x07\x12\x15\n\rfixed64_value\x18\x05 \x01(\x06\"\xc5\x01\n)CMsgSteamDatagramGameserverSessionRequest\x12\x36\n\x06ticket\x18\x01 \x01(\x0b\x32&.CMsgSteamDatagramGameServerAuthTicket\x12\x16\n\x0e\x63hallenge_time\x18\x03 \x01(\x07\x12\x11\n\tchallenge\x18\x04 \x01(\x06\x12\x15\n\rclient_cookie\x18\x05 \x01(\x07\x12\x1e\n\x16network_config_version\x18\x06 \x01(\r\"\x97\x01\n-CMsgSteamDatagramGameserverSessionEstablished\x12\x15\n\rclient_cookie\x18\x01 \x01(\x07\x12\x1b\n\x13gameserver_steam_id\x18\x03 \x01(\x06\x12\x1e\n\x16seconds_until_shutdown\x18\x04 \x01(\r\x12\x12\n\nsession_id\x18\x05 \x01(\r\"\x93\x01\n\x1a\x43MsgSteamDatagramNoSession\x12\x15\n\rclient_cookie\x18\x07 \x01(\x07\x12\x16\n\x0eyour_public_ip\x18\x02 \x01(\x07\x12\x13\n\x0bserver_time\x18\x03 \x01(\x07\x12\x11\n\tchallenge\x18\x04 \x01(\x06\x12\x1e\n\x16seconds_until_shutdown\x18\x05 \x01(\r\"=\n\x1b\x43MsgSteamDatagramDiagnostic\x12\x10\n\x08severity\x18\x01 \x01(\r\x12\x0c\n\x04text\x18\x02 \x01(\t\"\xef\x01\n CMsgSteamDatagramDataCenterState\x12\x42\n\x0c\x64\x61ta_centers\x18\x01 \x03(\x0b\x32,.CMsgSteamDatagramDataCenterState.DataCenter\x1a*\n\x06Server\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0f\n\x07ping_ms\x18\x02 \x01(\r\x1a[\n\nDataCenter\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12?\n\rserver_sample\x18\x02 \x03(\x0b\x32(.CMsgSteamDatagramDataCenterState.Server\"\x8b\x02\n\'CMsgSteamDatagramLinkInstantaneousStats\x12\x1f\n\x17out_packets_per_sec_x10\x18\x01 \x01(\r\x12\x19\n\x11out_bytes_per_sec\x18\x02 \x01(\r\x12\x1e\n\x16in_packets_per_sec_x10\x18\x03 \x01(\r\x12\x18\n\x10in_bytes_per_sec\x18\x04 \x01(\r\x12\x0f\n\x07ping_ms\x18\x05 \x01(\r\x12\x1b\n\x13packets_dropped_pct\x18\x06 \x01(\r\x12\"\n\x1apackets_weird_sequence_pct\x18\x07 \x01(\r\x12\x18\n\x10peak_jitter_usec\x18\x08 \x01(\r\"\xb5\t\n\"CMsgSteamDatagramLinkLifetimeStats\x12\x14\n\x0cpackets_sent\x18\x03 \x01(\x04\x12\x0f\n\x07kb_sent\x18\x04 \x01(\x04\x12\x14\n\x0cpackets_recv\x18\x05 \x01(\x04\x12\x0f\n\x07kb_recv\x18\x06 \x01(\x04\x12\x1e\n\x16packets_recv_sequenced\x18\x07 \x01(\x04\x12\x1c\n\x14packets_recv_dropped\x18\x08 \x01(\x04\x12!\n\x19packets_recv_out_of_order\x18\t \x01(\x04\x12\x1e\n\x16packets_recv_duplicate\x18\n \x01(\x04\x12\x1a\n\x12packets_recv_lurch\x18\x0b \x01(\x04\x12\x1d\n\x15quality_histogram_100\x18\x15 \x01(\r\x12\x1c\n\x14quality_histogram_99\x18\x16 \x01(\r\x12\x1c\n\x14quality_histogram_97\x18\x17 \x01(\r\x12\x1c\n\x14quality_histogram_95\x18\x18 \x01(\r\x12\x1c\n\x14quality_histogram_90\x18\x19 \x01(\r\x12\x1c\n\x14quality_histogram_75\x18\x1a \x01(\r\x12\x1c\n\x14quality_histogram_50\x18\x1b \x01(\r\x12\x1b\n\x13quality_histogram_1\x18\x1c \x01(\r\x12\x1e\n\x16quality_histogram_dead\x18\x1d \x01(\r\x12\x19\n\x11quality_ntile_2nd\x18\x1e \x01(\r\x12\x19\n\x11quality_ntile_5th\x18\x1f \x01(\r\x12\x1a\n\x12quality_ntile_25th\x18  \x01(\r\x12\x1a\n\x12quality_ntile_50th\x18! \x01(\r\x12\x19\n\x11ping_histogram_25\x18) \x01(\r\x12\x19\n\x11ping_histogram_50\x18* \x01(\r\x12\x19\n\x11ping_histogram_75\x18+ \x01(\r\x12\x1a\n\x12ping_histogram_100\x18, \x01(\r\x12\x1a\n\x12ping_histogram_125\x18- \x01(\r\x12\x1a\n\x12ping_histogram_150\x18. \x01(\r\x12\x1a\n\x12ping_histogram_200\x18/ \x01(\r\x12\x1a\n\x12ping_histogram_300\x18\x30 \x01(\r\x12\x1a\n\x12ping_histogram_max\x18\x31 \x01(\r\x12\x16\n\x0eping_ntile_5th\x18\x32 \x01(\r\x12\x17\n\x0fping_ntile_50th\x18\x33 \x01(\r\x12\x17\n\x0fping_ntile_75th\x18\x34 \x01(\r\x12\x17\n\x0fping_ntile_95th\x18\x35 \x01(\r\x12\x17\n\x0fping_ntile_98th\x18\x36 \x01(\r\x12#\n\x1bjitter_histogram_negligible\x18= \x01(\r\x12\x1a\n\x12jitter_histogram_1\x18> \x01(\r\x12\x1a\n\x12jitter_histogram_2\x18? \x01(\r\x12\x1a\n\x12jitter_histogram_5\x18@ \x01(\r\x12\x1b\n\x13jitter_histogram_10\x18\x41 \x01(\r\x12\x1b\n\x13jitter_histogram_20\x18\x42 \x01(\r\"\x9c\x01\n\"CMsgSteamDatagramConnectionQuality\x12?\n\rinstantaneous\x18\x01 \x01(\x0b\x32(.CMsgSteamDatagramLinkInstantaneousStats\x12\x35\n\x08lifetime\x18\x02 \x01(\x0b\x32#.CMsgSteamDatagramLinkLifetimeStats\"\xef\x01\n.CMsgSteamDatagramConnectionStatsClientToRouter\x12\x30\n\x03\x63\x32r\x18\x01 \x01(\x0b\x32#.CMsgSteamDatagramConnectionQuality\x12\x30\n\x03\x63\x32s\x18\x02 \x01(\x0b\x32#.CMsgSteamDatagramConnectionQuality\x12\x18\n\x10\x63lient_timestamp\x18\x03 \x01(\x07\x12\x15\n\rclient_cookie\x18\x08 \x01(\x07\x12\x13\n\x0bseq_num_c2r\x18\t \x01(\r\x12\x13\n\x0bseq_num_c2s\x18\n \x01(\r\"\xc5\x03\n.CMsgSteamDatagramConnectionStatsRouterToClient\x12\x30\n\x03r2c\x18\x01 \x01(\x0b\x32#.CMsgSteamDatagramConnectionQuality\x12\x30\n\x03s2c\x18\x02 \x01(\x0b\x32#.CMsgSteamDatagramConnectionQuality\x12$\n\x1c\x63lient_timestamp_from_router\x18\x03 \x01(\x07\x12$\n\x1c\x63lient_timestamp_from_server\x18\x04 \x01(\x07\x12!\n\x19router_gameserver_latency\x18\x05 \x01(\r\x12\x1e\n\x16seconds_until_shutdown\x18\x06 \x01(\r\x12\x1a\n\x12migrate_request_ip\x18\n \x01(\x07\x12\x1c\n\x14migrate_request_port\x18\x0b \x01(\r\x12%\n\x1dscoring_penalty_relay_cluster\x18\x0c \x01(\r\x12\x15\n\rclient_cookie\x18\x07 \x01(\x07\x12\x13\n\x0bseq_num_r2c\x18\x08 \x01(\r\x12\x13\n\x0bseq_num_s2c\x18\t \x01(\r\"\xa6\x02\n.CMsgSteamDatagramConnectionStatsRouterToServer\x12\x30\n\x03r2s\x18\x01 \x01(\x0b\x32#.CMsgSteamDatagramConnectionQuality\x12\x30\n\x03\x63\x32s\x18\x02 \x01(\x0b\x32#.CMsgSteamDatagramConnectionQuality\x12\x18\n\x10\x63lient_timestamp\x18\x03 \x01(\x07\x12\x18\n\x10router_timestamp\x18\x04 \x01(\x07\x12\x13\n\x0bseq_num_r2s\x18\x05 \x01(\r\x12\x13\n\x0bseq_num_c2s\x18\x06 \x01(\r\x12\x17\n\x0f\x63lient_steam_id\x18\x07 \x01(\x06\x12\x19\n\x11\x63lient_session_id\x18\x08 \x01(\r\"\xf2\x01\n.CMsgSteamDatagramConnectionStatsServerToRouter\x12\x30\n\x03s2r\x18\x01 \x01(\x0b\x32#.CMsgSteamDatagramConnectionQuality\x12\x30\n\x03s2c\x18\x02 \x01(\x0b\x32#.CMsgSteamDatagramConnectionQuality\x12\x13\n\x0bseq_num_s2r\x18\x03 \x01(\r\x12\x13\n\x0bseq_num_s2c\x18\x04 \x01(\r\x12\x17\n\x0f\x63lient_steam_id\x18\x05 \x01(\x06\x12\x19\n\x11\x63lient_session_id\x18\x06 \x01(\r\"A\n(CMsgSteamDatagramClientPingSampleRequest\x12\x15\n\rclient_cookie\x18\x01 \x01(\x07\"\xf6\x02\n&CMsgSteamDatagramClientPingSampleReply\x12\x15\n\rclient_cookie\x18\x01 \x01(\x07\x12P\n\x10routing_clusters\x18\x02 \x03(\x0b\x32\x36.CMsgSteamDatagramClientPingSampleReply.RoutingCluster\x12H\n\x0c\x64\x61ta_centers\x18\x03 \x03(\x0b\x32\x32.CMsgSteamDatagramClientPingSampleReply.DataCenter\x1aH\n\x0eRoutingCluster\x12\n\n\x02id\x18\x01 \x01(\x07\x12\x15\n\rfront_ping_ms\x18\x02 \x01(\r\x12\x13\n\x0b\x65\x32\x65_ping_ms\x18\x03 \x01(\r\x1aO\n\nDataCenter\x12\x16\n\x0e\x64\x61ta_center_id\x18\x01 \x01(\x07\x12\x14\n\x0cvia_relay_id\x18\x02 \x01(\x07\x12\x13\n\x0b\x65\x32\x65_ping_ms\x18\x03 \x01(\r\"\x8e\x05\n&CMsgSteamDatagramClientSwitchedPrimary\x12\x15\n\rclient_cookie\x18\x01 \x01(\x07\x12\x0f\n\x07\x66rom_ip\x18\x02 \x01(\x07\x12\x11\n\tfrom_port\x18\x03 \x01(\r\x12\x1b\n\x13\x66rom_router_cluster\x18\x04 \x01(\x07\x12\x18\n\x10\x66rom_active_time\x18\x05 \x01(\r\x12 \n\x18\x66rom_active_packets_recv\x18\x06 \x01(\r\x12\x1b\n\x13\x66rom_dropped_reason\x18\x07 \x01(\t\x12\x0e\n\x06gap_ms\x18\x08 \x01(\r\x12O\n\x10\x66rom_quality_now\x18\t \x01(\x0b\x32\x35.CMsgSteamDatagramClientSwitchedPrimary.RouterQuality\x12M\n\x0eto_quality_now\x18\n \x01(\x0b\x32\x35.CMsgSteamDatagramClientSwitchedPrimary.RouterQuality\x12P\n\x11\x66rom_quality_then\x18\x0b \x01(\x0b\x32\x35.CMsgSteamDatagramClientSwitchedPrimary.RouterQuality\x12N\n\x0fto_quality_then\x18\x0c \x01(\x0b\x32\x35.CMsgSteamDatagramClientSwitchedPrimary.RouterQuality\x1a\x61\n\rRouterQuality\x12\r\n\x05score\x18\x01 \x01(\r\x12\x12\n\nfront_ping\x18\x02 \x01(\r\x12\x11\n\tback_ping\x18\x03 \x01(\r\x12\x1a\n\x12seconds_until_down\x18\x04 \x01(\r\"\xd5\x02\n\x1d\x43MsgSteamDatagramRouterHealth\x12\x10\n\x08\x63pu_load\x18\x01 \x01(\x02\x12\x17\n\x0f\x61\x63tive_sessions\x18\x02 \x01(\r\x12\x15\n\rdata_pkts_sec\x18\x03 \x01(\r\x12\x16\n\x0eother_pkts_sec\x18\x04 \x01(\r\x12\x1e\n\x16seconds_until_shutdown\x18\x05 \x01(\r\x12\x19\n\x11\x63pu_cost_per_user\x18\x08 \x01(\x02\x12\x1b\n\x13\x63pu_cost_per_packet\x18\t \x01(\x02\x12?\n\x0c\x64\x61ta_centers\x18\x06 \x03(\x0b\x32).CMsgSteamDatagramRouterHealth.DataCenter\x12\r\n\x05magic\x18\x07 \x01(\x06\x1a\x32\n\nDataCenter\x12\x15\n\rdatacenter_id\x18\x01 \x01(\x07\x12\r\n\x05state\x18\x02 \x01(\r*\xa0\x06\n\x13\x45SteamDatagramMsgID\x12\x1f\n\x1bk_ESteamDatagramMsg_Invalid\x10\x00\x12)\n%k_ESteamDatagramMsg_RouterPingRequest\x10\x01\x12\'\n#k_ESteamDatagramMsg_RouterPingReply\x10\x02\x12-\n)k_ESteamDatagramMsg_GameserverPingRequest\x10\x03\x12+\n\'k_ESteamDatagramMsg_GameserverPingReply\x10\x04\x12\x30\n,k_ESteamDatagramMsg_GameserverSessionRequest\x10\x05\x12\x34\n0k_ESteamDatagramMsg_GameserverSessionEstablished\x10\x06\x12!\n\x1dk_ESteamDatagramMsg_NoSession\x10\x07\x12\"\n\x1ek_ESteamDatagramMsg_Diagnostic\x10\x08\x12*\n&k_ESteamDatagramMsg_DataClientToRouter\x10\t\x12*\n&k_ESteamDatagramMsg_DataRouterToServer\x10\n\x12*\n&k_ESteamDatagramMsg_DataServerToRouter\x10\x0b\x12*\n&k_ESteamDatagramMsg_DataRouterToClient\x10\x0c\x12\x1d\n\x19k_ESteamDatagramMsg_Stats\x10\r\x12/\n+k_ESteamDatagramMsg_ClientPingSampleRequest\x10\x0e\x12-\n)k_ESteamDatagramMsg_ClientPingSampleReply\x10\x0f\x12\x35\n1k_ESteamDatagramMsg_ClientToRouterSwitchedPrimary\x10\x10\x12#\n\x1fk_ESteamDatagramMsg_RelayHealth\x10\x11\x42\x03\x80\x01\x00')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_ESTEAMDATAGRAMMSGID = _descriptor.EnumDescriptor(
  name='ESteamDatagramMsgID',
  full_name='ESteamDatagramMsgID',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_Invalid', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_RouterPingRequest', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_RouterPingReply', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_GameserverPingRequest', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_GameserverPingReply', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_GameserverSessionRequest', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_GameserverSessionEstablished', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_NoSession', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_Diagnostic', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_DataClientToRouter', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_DataRouterToServer', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_DataServerToRouter', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_DataRouterToClient', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_Stats', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_ClientPingSampleRequest', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_ClientPingSampleReply', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_ClientToRouterSwitchedPrimary', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDatagramMsg_RelayHealth', index=17, number=17,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6177,
  serialized_end=6977,
)
_sym_db.RegisterEnumDescriptor(_ESTEAMDATAGRAMMSGID)

ESteamDatagramMsgID = enum_type_wrapper.EnumTypeWrapper(_ESTEAMDATAGRAMMSGID)
k_ESteamDatagramMsg_Invalid = 0
k_ESteamDatagramMsg_RouterPingRequest = 1
k_ESteamDatagramMsg_RouterPingReply = 2
k_ESteamDatagramMsg_GameserverPingRequest = 3
k_ESteamDatagramMsg_GameserverPingReply = 4
k_ESteamDatagramMsg_GameserverSessionRequest = 5
k_ESteamDatagramMsg_GameserverSessionEstablished = 6
k_ESteamDatagramMsg_NoSession = 7
k_ESteamDatagramMsg_Diagnostic = 8
k_ESteamDatagramMsg_DataClientToRouter = 9
k_ESteamDatagramMsg_DataRouterToServer = 10
k_ESteamDatagramMsg_DataServerToRouter = 11
k_ESteamDatagramMsg_DataRouterToClient = 12
k_ESteamDatagramMsg_Stats = 13
k_ESteamDatagramMsg_ClientPingSampleRequest = 14
k_ESteamDatagramMsg_ClientPingSampleReply = 15
k_ESteamDatagramMsg_ClientToRouterSwitchedPrimary = 16
k_ESteamDatagramMsg_RelayHealth = 17



_CMSGSTEAMDATAGRAMROUTERPINGREPLY = _descriptor.Descriptor(
  name='CMsgSteamDatagramRouterPingReply',
  full_name='CMsgSteamDatagramRouterPingReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_timestamp', full_name='CMsgSteamDatagramRouterPingReply.client_timestamp', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='latency_datacenter_ids', full_name='CMsgSteamDatagramRouterPingReply.latency_datacenter_ids', index=1,
      number=2, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='latency_ping_ms', full_name='CMsgSteamDatagramRouterPingReply.latency_ping_ms', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='your_public_ip', full_name='CMsgSteamDatagramRouterPingReply.your_public_ip', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_time', full_name='CMsgSteamDatagramRouterPingReply.server_time', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='challenge', full_name='CMsgSteamDatagramRouterPingReply.challenge', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seconds_until_shutdown', full_name='CMsgSteamDatagramRouterPingReply.seconds_until_shutdown', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_cookie', full_name='CMsgSteamDatagramRouterPingReply.client_cookie', index=7,
      number=8, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scoring_penalty_relay_cluster', full_name='CMsgSteamDatagramRouterPingReply.scoring_penalty_relay_cluster', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scoring_penalty_datacenter_ids', full_name='CMsgSteamDatagramRouterPingReply.scoring_penalty_datacenter_ids', index=9,
      number=10, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='scoring_penalty_values', full_name='CMsgSteamDatagramRouterPingReply.scoring_penalty_values', index=10,
      number=11, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=417,
)


_CMSGSTEAMDATAGRAMGAMESERVERPING = _descriptor.Descriptor(
  name='CMsgSteamDatagramGameserverPing',
  full_name='CMsgSteamDatagramGameserverPing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_session', full_name='CMsgSteamDatagramGameserverPing.client_session', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_steam_id', full_name='CMsgSteamDatagramGameserverPing.client_steam_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_timestamp', full_name='CMsgSteamDatagramGameserverPing.client_timestamp', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='router_timestamp', full_name='CMsgSteamDatagramGameserverPing.router_timestamp', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='router_gameserver_latency', full_name='CMsgSteamDatagramGameserverPing.router_gameserver_latency', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seq_number_router', full_name='CMsgSteamDatagramGameserverPing.seq_number_router', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seq_number_e2e', full_name='CMsgSteamDatagramGameserverPing.seq_number_e2e', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=640,
)


_CMSGSTEAMDATAGRAMGAMESERVERAUTHTICKET_EXTRAFIELD = _descriptor.Descriptor(
  name='ExtraField',
  full_name='CMsgSteamDatagramGameServerAuthTicket.ExtraField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgSteamDatagramGameServerAuthTicket.ExtraField.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='CMsgSteamDatagramGameServerAuthTicket.ExtraField.string_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='int32_value', full_name='CMsgSteamDatagramGameServerAuthTicket.ExtraField.int32_value', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fixed32_value', full_name='CMsgSteamDatagramGameServerAuthTicket.ExtraField.fixed32_value', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fixed64_value', full_name='CMsgSteamDatagramGameServerAuthTicket.ExtraField.fixed64_value', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=928,
  serialized_end=1043,
)

_CMSGSTEAMDATAGRAMGAMESERVERAUTHTICKET = _descriptor.Descriptor(
  name='CMsgSteamDatagramGameServerAuthTicket',
  full_name='CMsgSteamDatagramGameServerAuthTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_expiry', full_name='CMsgSteamDatagramGameServerAuthTicket.time_expiry', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='authorized_steam_id', full_name='CMsgSteamDatagramGameServerAuthTicket.authorized_steam_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='authorized_public_ip', full_name='CMsgSteamDatagramGameServerAuthTicket.authorized_public_ip', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gameserver_steam_id', full_name='CMsgSteamDatagramGameServerAuthTicket.gameserver_steam_id', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gameserver_net_id', full_name='CMsgSteamDatagramGameServerAuthTicket.gameserver_net_id', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signature', full_name='CMsgSteamDatagramGameServerAuthTicket.signature', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgSteamDatagramGameServerAuthTicket.app_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='extra_fields', full_name='CMsgSteamDatagramGameServerAuthTicket.extra_fields', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSTEAMDATAGRAMGAMESERVERAUTHTICKET_EXTRAFIELD, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=643,
  serialized_end=1043,
)


_CMSGSTEAMDATAGRAMGAMESERVERSESSIONREQUEST = _descriptor.Descriptor(
  name='CMsgSteamDatagramGameserverSessionRequest',
  full_name='CMsgSteamDatagramGameserverSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket', full_name='CMsgSteamDatagramGameserverSessionRequest.ticket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='challenge_time', full_name='CMsgSteamDatagramGameserverSessionRequest.challenge_time', index=1,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='challenge', full_name='CMsgSteamDatagramGameserverSessionRequest.challenge', index=2,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_cookie', full_name='CMsgSteamDatagramGameserverSessionRequest.client_cookie', index=3,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='network_config_version', full_name='CMsgSteamDatagramGameserverSessionRequest.network_config_version', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1046,
  serialized_end=1243,
)


_CMSGSTEAMDATAGRAMGAMESERVERSESSIONESTABLISHED = _descriptor.Descriptor(
  name='CMsgSteamDatagramGameserverSessionEstablished',
  full_name='CMsgSteamDatagramGameserverSessionEstablished',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_cookie', full_name='CMsgSteamDatagramGameserverSessionEstablished.client_cookie', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gameserver_steam_id', full_name='CMsgSteamDatagramGameserverSessionEstablished.gameserver_steam_id', index=1,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seconds_until_shutdown', full_name='CMsgSteamDatagramGameserverSessionEstablished.seconds_until_shutdown', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='CMsgSteamDatagramGameserverSessionEstablished.session_id', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1246,
  serialized_end=1397,
)


_CMSGSTEAMDATAGRAMNOSESSION = _descriptor.Descriptor(
  name='CMsgSteamDatagramNoSession',
  full_name='CMsgSteamDatagramNoSession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_cookie', full_name='CMsgSteamDatagramNoSession.client_cookie', index=0,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='your_public_ip', full_name='CMsgSteamDatagramNoSession.your_public_ip', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_time', full_name='CMsgSteamDatagramNoSession.server_time', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='challenge', full_name='CMsgSteamDatagramNoSession.challenge', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seconds_until_shutdown', full_name='CMsgSteamDatagramNoSession.seconds_until_shutdown', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1400,
  serialized_end=1547,
)


_CMSGSTEAMDATAGRAMDIAGNOSTIC = _descriptor.Descriptor(
  name='CMsgSteamDatagramDiagnostic',
  full_name='CMsgSteamDatagramDiagnostic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='severity', full_name='CMsgSteamDatagramDiagnostic.severity', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='CMsgSteamDatagramDiagnostic.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1549,
  serialized_end=1610,
)


_CMSGSTEAMDATAGRAMDATACENTERSTATE_SERVER = _descriptor.Descriptor(
  name='Server',
  full_name='CMsgSteamDatagramDataCenterState.Server',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='CMsgSteamDatagramDataCenterState.Server.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_ms', full_name='CMsgSteamDatagramDataCenterState.Server.ping_ms', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1717,
  serialized_end=1759,
)

_CMSGSTEAMDATAGRAMDATACENTERSTATE_DATACENTER = _descriptor.Descriptor(
  name='DataCenter',
  full_name='CMsgSteamDatagramDataCenterState.DataCenter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='CMsgSteamDatagramDataCenterState.DataCenter.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_sample', full_name='CMsgSteamDatagramDataCenterState.DataCenter.server_sample', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1761,
  serialized_end=1852,
)

_CMSGSTEAMDATAGRAMDATACENTERSTATE = _descriptor.Descriptor(
  name='CMsgSteamDatagramDataCenterState',
  full_name='CMsgSteamDatagramDataCenterState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_centers', full_name='CMsgSteamDatagramDataCenterState.data_centers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSTEAMDATAGRAMDATACENTERSTATE_SERVER, _CMSGSTEAMDATAGRAMDATACENTERSTATE_DATACENTER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1613,
  serialized_end=1852,
)


_CMSGSTEAMDATAGRAMLINKINSTANTANEOUSSTATS = _descriptor.Descriptor(
  name='CMsgSteamDatagramLinkInstantaneousStats',
  full_name='CMsgSteamDatagramLinkInstantaneousStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='out_packets_per_sec_x10', full_name='CMsgSteamDatagramLinkInstantaneousStats.out_packets_per_sec_x10', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='out_bytes_per_sec', full_name='CMsgSteamDatagramLinkInstantaneousStats.out_bytes_per_sec', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_packets_per_sec_x10', full_name='CMsgSteamDatagramLinkInstantaneousStats.in_packets_per_sec_x10', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_bytes_per_sec', full_name='CMsgSteamDatagramLinkInstantaneousStats.in_bytes_per_sec', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_ms', full_name='CMsgSteamDatagramLinkInstantaneousStats.ping_ms', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packets_dropped_pct', full_name='CMsgSteamDatagramLinkInstantaneousStats.packets_dropped_pct', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packets_weird_sequence_pct', full_name='CMsgSteamDatagramLinkInstantaneousStats.packets_weird_sequence_pct', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='peak_jitter_usec', full_name='CMsgSteamDatagramLinkInstantaneousStats.peak_jitter_usec', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1855,
  serialized_end=2122,
)


_CMSGSTEAMDATAGRAMLINKLIFETIMESTATS = _descriptor.Descriptor(
  name='CMsgSteamDatagramLinkLifetimeStats',
  full_name='CMsgSteamDatagramLinkLifetimeStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packets_sent', full_name='CMsgSteamDatagramLinkLifetimeStats.packets_sent', index=0,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kb_sent', full_name='CMsgSteamDatagramLinkLifetimeStats.kb_sent', index=1,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packets_recv', full_name='CMsgSteamDatagramLinkLifetimeStats.packets_recv', index=2,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kb_recv', full_name='CMsgSteamDatagramLinkLifetimeStats.kb_recv', index=3,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packets_recv_sequenced', full_name='CMsgSteamDatagramLinkLifetimeStats.packets_recv_sequenced', index=4,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packets_recv_dropped', full_name='CMsgSteamDatagramLinkLifetimeStats.packets_recv_dropped', index=5,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packets_recv_out_of_order', full_name='CMsgSteamDatagramLinkLifetimeStats.packets_recv_out_of_order', index=6,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packets_recv_duplicate', full_name='CMsgSteamDatagramLinkLifetimeStats.packets_recv_duplicate', index=7,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packets_recv_lurch', full_name='CMsgSteamDatagramLinkLifetimeStats.packets_recv_lurch', index=8,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality_histogram_100', full_name='CMsgSteamDatagramLinkLifetimeStats.quality_histogram_100', index=9,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality_histogram_99', full_name='CMsgSteamDatagramLinkLifetimeStats.quality_histogram_99', index=10,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality_histogram_97', full_name='CMsgSteamDatagramLinkLifetimeStats.quality_histogram_97', index=11,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality_histogram_95', full_name='CMsgSteamDatagramLinkLifetimeStats.quality_histogram_95', index=12,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality_histogram_90', full_name='CMsgSteamDatagramLinkLifetimeStats.quality_histogram_90', index=13,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality_histogram_75', full_name='CMsgSteamDatagramLinkLifetimeStats.quality_histogram_75', index=14,
      number=26, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality_histogram_50', full_name='CMsgSteamDatagramLinkLifetimeStats.quality_histogram_50', index=15,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality_histogram_1', full_name='CMsgSteamDatagramLinkLifetimeStats.quality_histogram_1', index=16,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality_histogram_dead', full_name='CMsgSteamDatagramLinkLifetimeStats.quality_histogram_dead', index=17,
      number=29, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality_ntile_2nd', full_name='CMsgSteamDatagramLinkLifetimeStats.quality_ntile_2nd', index=18,
      number=30, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality_ntile_5th', full_name='CMsgSteamDatagramLinkLifetimeStats.quality_ntile_5th', index=19,
      number=31, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality_ntile_25th', full_name='CMsgSteamDatagramLinkLifetimeStats.quality_ntile_25th', index=20,
      number=32, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality_ntile_50th', full_name='CMsgSteamDatagramLinkLifetimeStats.quality_ntile_50th', index=21,
      number=33, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_histogram_25', full_name='CMsgSteamDatagramLinkLifetimeStats.ping_histogram_25', index=22,
      number=41, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_histogram_50', full_name='CMsgSteamDatagramLinkLifetimeStats.ping_histogram_50', index=23,
      number=42, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_histogram_75', full_name='CMsgSteamDatagramLinkLifetimeStats.ping_histogram_75', index=24,
      number=43, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_histogram_100', full_name='CMsgSteamDatagramLinkLifetimeStats.ping_histogram_100', index=25,
      number=44, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_histogram_125', full_name='CMsgSteamDatagramLinkLifetimeStats.ping_histogram_125', index=26,
      number=45, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_histogram_150', full_name='CMsgSteamDatagramLinkLifetimeStats.ping_histogram_150', index=27,
      number=46, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_histogram_200', full_name='CMsgSteamDatagramLinkLifetimeStats.ping_histogram_200', index=28,
      number=47, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_histogram_300', full_name='CMsgSteamDatagramLinkLifetimeStats.ping_histogram_300', index=29,
      number=48, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_histogram_max', full_name='CMsgSteamDatagramLinkLifetimeStats.ping_histogram_max', index=30,
      number=49, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_ntile_5th', full_name='CMsgSteamDatagramLinkLifetimeStats.ping_ntile_5th', index=31,
      number=50, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_ntile_50th', full_name='CMsgSteamDatagramLinkLifetimeStats.ping_ntile_50th', index=32,
      number=51, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_ntile_75th', full_name='CMsgSteamDatagramLinkLifetimeStats.ping_ntile_75th', index=33,
      number=52, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_ntile_95th', full_name='CMsgSteamDatagramLinkLifetimeStats.ping_ntile_95th', index=34,
      number=53, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_ntile_98th', full_name='CMsgSteamDatagramLinkLifetimeStats.ping_ntile_98th', index=35,
      number=54, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='jitter_histogram_negligible', full_name='CMsgSteamDatagramLinkLifetimeStats.jitter_histogram_negligible', index=36,
      number=61, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='jitter_histogram_1', full_name='CMsgSteamDatagramLinkLifetimeStats.jitter_histogram_1', index=37,
      number=62, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='jitter_histogram_2', full_name='CMsgSteamDatagramLinkLifetimeStats.jitter_histogram_2', index=38,
      number=63, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='jitter_histogram_5', full_name='CMsgSteamDatagramLinkLifetimeStats.jitter_histogram_5', index=39,
      number=64, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='jitter_histogram_10', full_name='CMsgSteamDatagramLinkLifetimeStats.jitter_histogram_10', index=40,
      number=65, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='jitter_histogram_20', full_name='CMsgSteamDatagramLinkLifetimeStats.jitter_histogram_20', index=41,
      number=66, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2125,
  serialized_end=3330,
)


_CMSGSTEAMDATAGRAMCONNECTIONQUALITY = _descriptor.Descriptor(
  name='CMsgSteamDatagramConnectionQuality',
  full_name='CMsgSteamDatagramConnectionQuality',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instantaneous', full_name='CMsgSteamDatagramConnectionQuality.instantaneous', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lifetime', full_name='CMsgSteamDatagramConnectionQuality.lifetime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3333,
  serialized_end=3489,
)


_CMSGSTEAMDATAGRAMCONNECTIONSTATSCLIENTTOROUTER = _descriptor.Descriptor(
  name='CMsgSteamDatagramConnectionStatsClientToRouter',
  full_name='CMsgSteamDatagramConnectionStatsClientToRouter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='c2r', full_name='CMsgSteamDatagramConnectionStatsClientToRouter.c2r', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c2s', full_name='CMsgSteamDatagramConnectionStatsClientToRouter.c2s', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_timestamp', full_name='CMsgSteamDatagramConnectionStatsClientToRouter.client_timestamp', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_cookie', full_name='CMsgSteamDatagramConnectionStatsClientToRouter.client_cookie', index=3,
      number=8, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seq_num_c2r', full_name='CMsgSteamDatagramConnectionStatsClientToRouter.seq_num_c2r', index=4,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seq_num_c2s', full_name='CMsgSteamDatagramConnectionStatsClientToRouter.seq_num_c2s', index=5,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3492,
  serialized_end=3731,
)


_CMSGSTEAMDATAGRAMCONNECTIONSTATSROUTERTOCLIENT = _descriptor.Descriptor(
  name='CMsgSteamDatagramConnectionStatsRouterToClient',
  full_name='CMsgSteamDatagramConnectionStatsRouterToClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='r2c', full_name='CMsgSteamDatagramConnectionStatsRouterToClient.r2c', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='s2c', full_name='CMsgSteamDatagramConnectionStatsRouterToClient.s2c', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_timestamp_from_router', full_name='CMsgSteamDatagramConnectionStatsRouterToClient.client_timestamp_from_router', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_timestamp_from_server', full_name='CMsgSteamDatagramConnectionStatsRouterToClient.client_timestamp_from_server', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='router_gameserver_latency', full_name='CMsgSteamDatagramConnectionStatsRouterToClient.router_gameserver_latency', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seconds_until_shutdown', full_name='CMsgSteamDatagramConnectionStatsRouterToClient.seconds_until_shutdown', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='migrate_request_ip', full_name='CMsgSteamDatagramConnectionStatsRouterToClient.migrate_request_ip', index=6,
      number=10, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='migrate_request_port', full_name='CMsgSteamDatagramConnectionStatsRouterToClient.migrate_request_port', index=7,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scoring_penalty_relay_cluster', full_name='CMsgSteamDatagramConnectionStatsRouterToClient.scoring_penalty_relay_cluster', index=8,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_cookie', full_name='CMsgSteamDatagramConnectionStatsRouterToClient.client_cookie', index=9,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seq_num_r2c', full_name='CMsgSteamDatagramConnectionStatsRouterToClient.seq_num_r2c', index=10,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seq_num_s2c', full_name='CMsgSteamDatagramConnectionStatsRouterToClient.seq_num_s2c', index=11,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3734,
  serialized_end=4187,
)


_CMSGSTEAMDATAGRAMCONNECTIONSTATSROUTERTOSERVER = _descriptor.Descriptor(
  name='CMsgSteamDatagramConnectionStatsRouterToServer',
  full_name='CMsgSteamDatagramConnectionStatsRouterToServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='r2s', full_name='CMsgSteamDatagramConnectionStatsRouterToServer.r2s', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c2s', full_name='CMsgSteamDatagramConnectionStatsRouterToServer.c2s', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_timestamp', full_name='CMsgSteamDatagramConnectionStatsRouterToServer.client_timestamp', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='router_timestamp', full_name='CMsgSteamDatagramConnectionStatsRouterToServer.router_timestamp', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seq_num_r2s', full_name='CMsgSteamDatagramConnectionStatsRouterToServer.seq_num_r2s', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seq_num_c2s', full_name='CMsgSteamDatagramConnectionStatsRouterToServer.seq_num_c2s', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_steam_id', full_name='CMsgSteamDatagramConnectionStatsRouterToServer.client_steam_id', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_session_id', full_name='CMsgSteamDatagramConnectionStatsRouterToServer.client_session_id', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4190,
  serialized_end=4484,
)


_CMSGSTEAMDATAGRAMCONNECTIONSTATSSERVERTOROUTER = _descriptor.Descriptor(
  name='CMsgSteamDatagramConnectionStatsServerToRouter',
  full_name='CMsgSteamDatagramConnectionStatsServerToRouter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='s2r', full_name='CMsgSteamDatagramConnectionStatsServerToRouter.s2r', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='s2c', full_name='CMsgSteamDatagramConnectionStatsServerToRouter.s2c', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seq_num_s2r', full_name='CMsgSteamDatagramConnectionStatsServerToRouter.seq_num_s2r', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seq_num_s2c', full_name='CMsgSteamDatagramConnectionStatsServerToRouter.seq_num_s2c', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_steam_id', full_name='CMsgSteamDatagramConnectionStatsServerToRouter.client_steam_id', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_session_id', full_name='CMsgSteamDatagramConnectionStatsServerToRouter.client_session_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4487,
  serialized_end=4729,
)


_CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREQUEST = _descriptor.Descriptor(
  name='CMsgSteamDatagramClientPingSampleRequest',
  full_name='CMsgSteamDatagramClientPingSampleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_cookie', full_name='CMsgSteamDatagramClientPingSampleRequest.client_cookie', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4731,
  serialized_end=4796,
)


_CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY_ROUTINGCLUSTER = _descriptor.Descriptor(
  name='RoutingCluster',
  full_name='CMsgSteamDatagramClientPingSampleReply.RoutingCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgSteamDatagramClientPingSampleReply.RoutingCluster.id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='front_ping_ms', full_name='CMsgSteamDatagramClientPingSampleReply.RoutingCluster.front_ping_ms', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e2e_ping_ms', full_name='CMsgSteamDatagramClientPingSampleReply.RoutingCluster.e2e_ping_ms', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5020,
  serialized_end=5092,
)

_CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY_DATACENTER = _descriptor.Descriptor(
  name='DataCenter',
  full_name='CMsgSteamDatagramClientPingSampleReply.DataCenter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_center_id', full_name='CMsgSteamDatagramClientPingSampleReply.DataCenter.data_center_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='via_relay_id', full_name='CMsgSteamDatagramClientPingSampleReply.DataCenter.via_relay_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e2e_ping_ms', full_name='CMsgSteamDatagramClientPingSampleReply.DataCenter.e2e_ping_ms', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5094,
  serialized_end=5173,
)

_CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY = _descriptor.Descriptor(
  name='CMsgSteamDatagramClientPingSampleReply',
  full_name='CMsgSteamDatagramClientPingSampleReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_cookie', full_name='CMsgSteamDatagramClientPingSampleReply.client_cookie', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='routing_clusters', full_name='CMsgSteamDatagramClientPingSampleReply.routing_clusters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data_centers', full_name='CMsgSteamDatagramClientPingSampleReply.data_centers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY_ROUTINGCLUSTER, _CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY_DATACENTER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4799,
  serialized_end=5173,
)


_CMSGSTEAMDATAGRAMCLIENTSWITCHEDPRIMARY_ROUTERQUALITY = _descriptor.Descriptor(
  name='RouterQuality',
  full_name='CMsgSteamDatagramClientSwitchedPrimary.RouterQuality',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgSteamDatagramClientSwitchedPrimary.RouterQuality.score', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='front_ping', full_name='CMsgSteamDatagramClientSwitchedPrimary.RouterQuality.front_ping', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='back_ping', full_name='CMsgSteamDatagramClientSwitchedPrimary.RouterQuality.back_ping', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seconds_until_down', full_name='CMsgSteamDatagramClientSwitchedPrimary.RouterQuality.seconds_until_down', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5733,
  serialized_end=5830,
)

_CMSGSTEAMDATAGRAMCLIENTSWITCHEDPRIMARY = _descriptor.Descriptor(
  name='CMsgSteamDatagramClientSwitchedPrimary',
  full_name='CMsgSteamDatagramClientSwitchedPrimary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_cookie', full_name='CMsgSteamDatagramClientSwitchedPrimary.client_cookie', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_ip', full_name='CMsgSteamDatagramClientSwitchedPrimary.from_ip', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_port', full_name='CMsgSteamDatagramClientSwitchedPrimary.from_port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_router_cluster', full_name='CMsgSteamDatagramClientSwitchedPrimary.from_router_cluster', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_active_time', full_name='CMsgSteamDatagramClientSwitchedPrimary.from_active_time', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_active_packets_recv', full_name='CMsgSteamDatagramClientSwitchedPrimary.from_active_packets_recv', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_dropped_reason', full_name='CMsgSteamDatagramClientSwitchedPrimary.from_dropped_reason', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gap_ms', full_name='CMsgSteamDatagramClientSwitchedPrimary.gap_ms', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_quality_now', full_name='CMsgSteamDatagramClientSwitchedPrimary.from_quality_now', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='to_quality_now', full_name='CMsgSteamDatagramClientSwitchedPrimary.to_quality_now', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_quality_then', full_name='CMsgSteamDatagramClientSwitchedPrimary.from_quality_then', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='to_quality_then', full_name='CMsgSteamDatagramClientSwitchedPrimary.to_quality_then', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSTEAMDATAGRAMCLIENTSWITCHEDPRIMARY_ROUTERQUALITY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5176,
  serialized_end=5830,
)


_CMSGSTEAMDATAGRAMROUTERHEALTH_DATACENTER = _descriptor.Descriptor(
  name='DataCenter',
  full_name='CMsgSteamDatagramRouterHealth.DataCenter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='datacenter_id', full_name='CMsgSteamDatagramRouterHealth.DataCenter.datacenter_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='CMsgSteamDatagramRouterHealth.DataCenter.state', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6124,
  serialized_end=6174,
)

_CMSGSTEAMDATAGRAMROUTERHEALTH = _descriptor.Descriptor(
  name='CMsgSteamDatagramRouterHealth',
  full_name='CMsgSteamDatagramRouterHealth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpu_load', full_name='CMsgSteamDatagramRouterHealth.cpu_load', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active_sessions', full_name='CMsgSteamDatagramRouterHealth.active_sessions', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data_pkts_sec', full_name='CMsgSteamDatagramRouterHealth.data_pkts_sec', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='other_pkts_sec', full_name='CMsgSteamDatagramRouterHealth.other_pkts_sec', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seconds_until_shutdown', full_name='CMsgSteamDatagramRouterHealth.seconds_until_shutdown', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpu_cost_per_user', full_name='CMsgSteamDatagramRouterHealth.cpu_cost_per_user', index=5,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpu_cost_per_packet', full_name='CMsgSteamDatagramRouterHealth.cpu_cost_per_packet', index=6,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data_centers', full_name='CMsgSteamDatagramRouterHealth.data_centers', index=7,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='magic', full_name='CMsgSteamDatagramRouterHealth.magic', index=8,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSTEAMDATAGRAMROUTERHEALTH_DATACENTER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5833,
  serialized_end=6174,
)

_CMSGSTEAMDATAGRAMGAMESERVERAUTHTICKET_EXTRAFIELD.containing_type = _CMSGSTEAMDATAGRAMGAMESERVERAUTHTICKET
_CMSGSTEAMDATAGRAMGAMESERVERAUTHTICKET.fields_by_name['extra_fields'].message_type = _CMSGSTEAMDATAGRAMGAMESERVERAUTHTICKET_EXTRAFIELD
_CMSGSTEAMDATAGRAMGAMESERVERSESSIONREQUEST.fields_by_name['ticket'].message_type = _CMSGSTEAMDATAGRAMGAMESERVERAUTHTICKET
_CMSGSTEAMDATAGRAMDATACENTERSTATE_SERVER.containing_type = _CMSGSTEAMDATAGRAMDATACENTERSTATE
_CMSGSTEAMDATAGRAMDATACENTERSTATE_DATACENTER.fields_by_name['server_sample'].message_type = _CMSGSTEAMDATAGRAMDATACENTERSTATE_SERVER
_CMSGSTEAMDATAGRAMDATACENTERSTATE_DATACENTER.containing_type = _CMSGSTEAMDATAGRAMDATACENTERSTATE
_CMSGSTEAMDATAGRAMDATACENTERSTATE.fields_by_name['data_centers'].message_type = _CMSGSTEAMDATAGRAMDATACENTERSTATE_DATACENTER
_CMSGSTEAMDATAGRAMCONNECTIONQUALITY.fields_by_name['instantaneous'].message_type = _CMSGSTEAMDATAGRAMLINKINSTANTANEOUSSTATS
_CMSGSTEAMDATAGRAMCONNECTIONQUALITY.fields_by_name['lifetime'].message_type = _CMSGSTEAMDATAGRAMLINKLIFETIMESTATS
_CMSGSTEAMDATAGRAMCONNECTIONSTATSCLIENTTOROUTER.fields_by_name['c2r'].message_type = _CMSGSTEAMDATAGRAMCONNECTIONQUALITY
_CMSGSTEAMDATAGRAMCONNECTIONSTATSCLIENTTOROUTER.fields_by_name['c2s'].message_type = _CMSGSTEAMDATAGRAMCONNECTIONQUALITY
_CMSGSTEAMDATAGRAMCONNECTIONSTATSROUTERTOCLIENT.fields_by_name['r2c'].message_type = _CMSGSTEAMDATAGRAMCONNECTIONQUALITY
_CMSGSTEAMDATAGRAMCONNECTIONSTATSROUTERTOCLIENT.fields_by_name['s2c'].message_type = _CMSGSTEAMDATAGRAMCONNECTIONQUALITY
_CMSGSTEAMDATAGRAMCONNECTIONSTATSROUTERTOSERVER.fields_by_name['r2s'].message_type = _CMSGSTEAMDATAGRAMCONNECTIONQUALITY
_CMSGSTEAMDATAGRAMCONNECTIONSTATSROUTERTOSERVER.fields_by_name['c2s'].message_type = _CMSGSTEAMDATAGRAMCONNECTIONQUALITY
_CMSGSTEAMDATAGRAMCONNECTIONSTATSSERVERTOROUTER.fields_by_name['s2r'].message_type = _CMSGSTEAMDATAGRAMCONNECTIONQUALITY
_CMSGSTEAMDATAGRAMCONNECTIONSTATSSERVERTOROUTER.fields_by_name['s2c'].message_type = _CMSGSTEAMDATAGRAMCONNECTIONQUALITY
_CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY_ROUTINGCLUSTER.containing_type = _CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY
_CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY_DATACENTER.containing_type = _CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY
_CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY.fields_by_name['routing_clusters'].message_type = _CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY_ROUTINGCLUSTER
_CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY.fields_by_name['data_centers'].message_type = _CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY_DATACENTER
_CMSGSTEAMDATAGRAMCLIENTSWITCHEDPRIMARY_ROUTERQUALITY.containing_type = _CMSGSTEAMDATAGRAMCLIENTSWITCHEDPRIMARY
_CMSGSTEAMDATAGRAMCLIENTSWITCHEDPRIMARY.fields_by_name['from_quality_now'].message_type = _CMSGSTEAMDATAGRAMCLIENTSWITCHEDPRIMARY_ROUTERQUALITY
_CMSGSTEAMDATAGRAMCLIENTSWITCHEDPRIMARY.fields_by_name['to_quality_now'].message_type = _CMSGSTEAMDATAGRAMCLIENTSWITCHEDPRIMARY_ROUTERQUALITY
_CMSGSTEAMDATAGRAMCLIENTSWITCHEDPRIMARY.fields_by_name['from_quality_then'].message_type = _CMSGSTEAMDATAGRAMCLIENTSWITCHEDPRIMARY_ROUTERQUALITY
_CMSGSTEAMDATAGRAMCLIENTSWITCHEDPRIMARY.fields_by_name['to_quality_then'].message_type = _CMSGSTEAMDATAGRAMCLIENTSWITCHEDPRIMARY_ROUTERQUALITY
_CMSGSTEAMDATAGRAMROUTERHEALTH_DATACENTER.containing_type = _CMSGSTEAMDATAGRAMROUTERHEALTH
_CMSGSTEAMDATAGRAMROUTERHEALTH.fields_by_name['data_centers'].message_type = _CMSGSTEAMDATAGRAMROUTERHEALTH_DATACENTER
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramRouterPingReply'] = _CMSGSTEAMDATAGRAMROUTERPINGREPLY
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramGameserverPing'] = _CMSGSTEAMDATAGRAMGAMESERVERPING
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramGameServerAuthTicket'] = _CMSGSTEAMDATAGRAMGAMESERVERAUTHTICKET
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramGameserverSessionRequest'] = _CMSGSTEAMDATAGRAMGAMESERVERSESSIONREQUEST
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramGameserverSessionEstablished'] = _CMSGSTEAMDATAGRAMGAMESERVERSESSIONESTABLISHED
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramNoSession'] = _CMSGSTEAMDATAGRAMNOSESSION
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramDiagnostic'] = _CMSGSTEAMDATAGRAMDIAGNOSTIC
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramDataCenterState'] = _CMSGSTEAMDATAGRAMDATACENTERSTATE
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramLinkInstantaneousStats'] = _CMSGSTEAMDATAGRAMLINKINSTANTANEOUSSTATS
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramLinkLifetimeStats'] = _CMSGSTEAMDATAGRAMLINKLIFETIMESTATS
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramConnectionQuality'] = _CMSGSTEAMDATAGRAMCONNECTIONQUALITY
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramConnectionStatsClientToRouter'] = _CMSGSTEAMDATAGRAMCONNECTIONSTATSCLIENTTOROUTER
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramConnectionStatsRouterToClient'] = _CMSGSTEAMDATAGRAMCONNECTIONSTATSROUTERTOCLIENT
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramConnectionStatsRouterToServer'] = _CMSGSTEAMDATAGRAMCONNECTIONSTATSROUTERTOSERVER
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramConnectionStatsServerToRouter'] = _CMSGSTEAMDATAGRAMCONNECTIONSTATSSERVERTOROUTER
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramClientPingSampleRequest'] = _CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREQUEST
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramClientPingSampleReply'] = _CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramClientSwitchedPrimary'] = _CMSGSTEAMDATAGRAMCLIENTSWITCHEDPRIMARY
DESCRIPTOR.message_types_by_name['CMsgSteamDatagramRouterHealth'] = _CMSGSTEAMDATAGRAMROUTERHEALTH
DESCRIPTOR.enum_types_by_name['ESteamDatagramMsgID'] = _ESTEAMDATAGRAMMSGID

CMsgSteamDatagramRouterPingReply = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramRouterPingReply', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTEAMDATAGRAMROUTERPINGREPLY,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramRouterPingReply)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramRouterPingReply)

CMsgSteamDatagramGameserverPing = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramGameserverPing', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTEAMDATAGRAMGAMESERVERPING,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramGameserverPing)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramGameserverPing)

CMsgSteamDatagramGameServerAuthTicket = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramGameServerAuthTicket', (_message.Message,), dict(

  ExtraField = _reflection.GeneratedProtocolMessageType('ExtraField', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSTEAMDATAGRAMGAMESERVERAUTHTICKET_EXTRAFIELD,
    __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgSteamDatagramGameServerAuthTicket.ExtraField)
    ))
  ,
  DESCRIPTOR = _CMSGSTEAMDATAGRAMGAMESERVERAUTHTICKET,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramGameServerAuthTicket)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramGameServerAuthTicket)
_sym_db.RegisterMessage(CMsgSteamDatagramGameServerAuthTicket.ExtraField)

CMsgSteamDatagramGameserverSessionRequest = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramGameserverSessionRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTEAMDATAGRAMGAMESERVERSESSIONREQUEST,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramGameserverSessionRequest)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramGameserverSessionRequest)

CMsgSteamDatagramGameserverSessionEstablished = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramGameserverSessionEstablished', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTEAMDATAGRAMGAMESERVERSESSIONESTABLISHED,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramGameserverSessionEstablished)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramGameserverSessionEstablished)

CMsgSteamDatagramNoSession = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramNoSession', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTEAMDATAGRAMNOSESSION,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramNoSession)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramNoSession)

CMsgSteamDatagramDiagnostic = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramDiagnostic', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTEAMDATAGRAMDIAGNOSTIC,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramDiagnostic)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramDiagnostic)

CMsgSteamDatagramDataCenterState = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramDataCenterState', (_message.Message,), dict(

  Server = _reflection.GeneratedProtocolMessageType('Server', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSTEAMDATAGRAMDATACENTERSTATE_SERVER,
    __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgSteamDatagramDataCenterState.Server)
    ))
  ,

  DataCenter = _reflection.GeneratedProtocolMessageType('DataCenter', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSTEAMDATAGRAMDATACENTERSTATE_DATACENTER,
    __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgSteamDatagramDataCenterState.DataCenter)
    ))
  ,
  DESCRIPTOR = _CMSGSTEAMDATAGRAMDATACENTERSTATE,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramDataCenterState)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramDataCenterState)
_sym_db.RegisterMessage(CMsgSteamDatagramDataCenterState.Server)
_sym_db.RegisterMessage(CMsgSteamDatagramDataCenterState.DataCenter)

CMsgSteamDatagramLinkInstantaneousStats = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramLinkInstantaneousStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTEAMDATAGRAMLINKINSTANTANEOUSSTATS,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramLinkInstantaneousStats)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramLinkInstantaneousStats)

CMsgSteamDatagramLinkLifetimeStats = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramLinkLifetimeStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTEAMDATAGRAMLINKLIFETIMESTATS,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramLinkLifetimeStats)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramLinkLifetimeStats)

CMsgSteamDatagramConnectionQuality = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramConnectionQuality', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTEAMDATAGRAMCONNECTIONQUALITY,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramConnectionQuality)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramConnectionQuality)

CMsgSteamDatagramConnectionStatsClientToRouter = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramConnectionStatsClientToRouter', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTEAMDATAGRAMCONNECTIONSTATSCLIENTTOROUTER,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramConnectionStatsClientToRouter)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramConnectionStatsClientToRouter)

CMsgSteamDatagramConnectionStatsRouterToClient = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramConnectionStatsRouterToClient', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTEAMDATAGRAMCONNECTIONSTATSROUTERTOCLIENT,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramConnectionStatsRouterToClient)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramConnectionStatsRouterToClient)

CMsgSteamDatagramConnectionStatsRouterToServer = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramConnectionStatsRouterToServer', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTEAMDATAGRAMCONNECTIONSTATSROUTERTOSERVER,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramConnectionStatsRouterToServer)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramConnectionStatsRouterToServer)

CMsgSteamDatagramConnectionStatsServerToRouter = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramConnectionStatsServerToRouter', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTEAMDATAGRAMCONNECTIONSTATSSERVERTOROUTER,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramConnectionStatsServerToRouter)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramConnectionStatsServerToRouter)

CMsgSteamDatagramClientPingSampleRequest = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramClientPingSampleRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREQUEST,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramClientPingSampleRequest)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramClientPingSampleRequest)

CMsgSteamDatagramClientPingSampleReply = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramClientPingSampleReply', (_message.Message,), dict(

  RoutingCluster = _reflection.GeneratedProtocolMessageType('RoutingCluster', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY_ROUTINGCLUSTER,
    __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgSteamDatagramClientPingSampleReply.RoutingCluster)
    ))
  ,

  DataCenter = _reflection.GeneratedProtocolMessageType('DataCenter', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY_DATACENTER,
    __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgSteamDatagramClientPingSampleReply.DataCenter)
    ))
  ,
  DESCRIPTOR = _CMSGSTEAMDATAGRAMCLIENTPINGSAMPLEREPLY,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramClientPingSampleReply)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramClientPingSampleReply)
_sym_db.RegisterMessage(CMsgSteamDatagramClientPingSampleReply.RoutingCluster)
_sym_db.RegisterMessage(CMsgSteamDatagramClientPingSampleReply.DataCenter)

CMsgSteamDatagramClientSwitchedPrimary = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramClientSwitchedPrimary', (_message.Message,), dict(

  RouterQuality = _reflection.GeneratedProtocolMessageType('RouterQuality', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSTEAMDATAGRAMCLIENTSWITCHEDPRIMARY_ROUTERQUALITY,
    __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgSteamDatagramClientSwitchedPrimary.RouterQuality)
    ))
  ,
  DESCRIPTOR = _CMSGSTEAMDATAGRAMCLIENTSWITCHEDPRIMARY,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramClientSwitchedPrimary)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramClientSwitchedPrimary)
_sym_db.RegisterMessage(CMsgSteamDatagramClientSwitchedPrimary.RouterQuality)

CMsgSteamDatagramRouterHealth = _reflection.GeneratedProtocolMessageType('CMsgSteamDatagramRouterHealth', (_message.Message,), dict(

  DataCenter = _reflection.GeneratedProtocolMessageType('DataCenter', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSTEAMDATAGRAMROUTERHEALTH_DATACENTER,
    __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgSteamDatagramRouterHealth.DataCenter)
    ))
  ,
  DESCRIPTOR = _CMSGSTEAMDATAGRAMROUTERHEALTH,
  __module__ = 'demoparser.protobufs.steamdatagram_messages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSteamDatagramRouterHealth)
  ))
_sym_db.RegisterMessage(CMsgSteamDatagramRouterHealth)
_sym_db.RegisterMessage(CMsgSteamDatagramRouterHealth.DataCenter)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\200\001\000'))
_CMSGSTEAMDATAGRAMROUTERPINGREPLY.fields_by_name['latency_datacenter_ids'].has_options = True
_CMSGSTEAMDATAGRAMROUTERPINGREPLY.fields_by_name['latency_datacenter_ids']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_CMSGSTEAMDATAGRAMROUTERPINGREPLY.fields_by_name['latency_ping_ms'].has_options = True
_CMSGSTEAMDATAGRAMROUTERPINGREPLY.fields_by_name['latency_ping_ms']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_CMSGSTEAMDATAGRAMROUTERPINGREPLY.fields_by_name['scoring_penalty_datacenter_ids'].has_options = True
_CMSGSTEAMDATAGRAMROUTERPINGREPLY.fields_by_name['scoring_penalty_datacenter_ids']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_CMSGSTEAMDATAGRAMROUTERPINGREPLY.fields_by_name['scoring_penalty_values'].has_options = True
_CMSGSTEAMDATAGRAMROUTERPINGREPLY.fields_by_name['scoring_penalty_values']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)



from cython.operator cimport dereference
from demoparser.bitbuffer cimport Bitbuffer
from demoparser import consts

from libc.math cimport ceil, log2, sqrt, NAN, isnan
cimport cython


cdef class Decoder:
    """Decode a property.

    Properties of server classes are encoded differently depending
    on the type of the property.

    :param buf: Raw buffer data used for decoding
    :type buf: Bitbuffer
    :param prop: Property to decode
    :type prop: object
    """

    def __cinit__(self, Bitbuffer buf, object prop):
        self.buf = buf
        self.fprop = prop
        self.prop = prop['prop']
        self.flags = self.prop.flags

    cpdef object decode(self):
        assert self.prop.type != PropTypes.DPT_DataTable
        cdef unsigned char prop_type = self.prop.type

        if prop_type == PropTypes.DPT_Int:
            ret = self.decode_int()
        elif prop_type == PropTypes.DPT_Float:
            ret = self.decode_float()
        elif prop_type == PropTypes.DPT_Vector:
            ret = self.decode_vector()
        elif prop_type == PropTypes.DPT_VectorXY:
            ret = self.decode_vector_xy()
        elif prop_type == PropTypes.DPT_String:
            ret = self.decode_string()
        elif prop_type == PropTypes.DPT_Int64:
            ret = self.decode_int64()
        elif prop_type == PropTypes.DPT_Array:
            ret = self.decode_array()
        else:
            raise Exception("Unsupported prop type")

        return ret

    cpdef long decode_int(self):
        """Decode an integer.

        Reads the number of bits specified in the
        num_bits field of the property. If the property
        has the SPROP_UNSIGNED flag set the number will be
        read as an unsigned int.
        """
        cdef long ret
        cdef int num_bits = self.prop.num_bits

        if self.flags & PropFlags.SPROP_UNSIGNED != 0:
            if num_bits == 1:
                ret = self.buf.read_bit()
            else:
                ret = self.buf.read_uint_bits(num_bits)
        else:
            ret = self.buf.read_sint_bits(num_bits)
        return ret

    @cython.cdivision(True)
    cpdef float decode_float(self):
        """Decode a floating point value.

        First the value is decoded as a special float. If that
        returns NaN then a normal floating point value is calculated.
        """
        cdef float special = self.decode_special_float()
        if not isnan(special):
            return special

        cdef int interp
        cdef float val
        cdef int num_bits = self.prop.num_bits
        cdef float high_value = self.prop.high_value
        cdef float low_value = self.prop.low_value

        interp = self.buf.read_uint_bits(num_bits)
        val = interp / ((1 << num_bits) - 1)
        val = low_value + (high_value - low_value) * val

        return val

    cpdef dict decode_vector(self):
        """Decode a vector.

        :returns: vector
        """
        cdef bint sign
        cdef float sum_sqr, x, y, z

        x = self.decode_float()
        y = self.decode_float()

        if (self.flags & PropFlags.SPROP_NORMAL) == 0:
            z = self.decode_float()
        else:
            sign = self.buf.read_bit()
            sum_sqr = (x * x) + (y * y)
            if sum_sqr < 1.0:
                z = sqrt(1.0 - sum_sqr)
            else:
                z = 0.0

            if sign:
                z = -z

        return {
            'x': x,
            'y': y,
            'z': z
        }

    cpdef dict decode_vector_xy(self):
        """Decode a two-element vector.

        This only reads the X and Y coordinates for
        the vector and sets the Z coordinate to 0.0

        :returns: vector
        """
        cdef float x, y
        x = self.decode_float()
        y = self.decode_float()
        return {
            'x': x,
            'y': y,
            'z': 0.0
        }

    cpdef str decode_string(self):
        r"""Decode a string.

        A fixed number of bits are read which may be
        more than the string's length (i.e. some bits
        are read after a \0 is encountered).

        :returns: str
        """
        cdef unsigned int length = self.buf.read_uint_bits(9)
        if not length:
            return ""
        string = self.buf.read_string(length)
        return string

    def decode_int64(self):
        """Decode a 64-bit integer.

        CS:GO demos don't appear to contain 64-bit ints.
        """
        assert False, 'int64'

    cpdef list decode_array(self):
        """Decode array.

        Arrays contain one or more elements (including arrays) which
        are recursively decoded.
        """
        cdef unsigned int bits, idx, num_elements

        max_elements = self.prop.num_elements
        bits = (<unsigned int>ceil(log2(max_elements))) + 1
        num_elements = self.buf.read_uint_bits(bits)

        elements = []
        for idx in range(num_elements):
            prop = {'prop': self.fprop['array_element_prop']}
            val = Decoder(self.buf, prop).decode()
            elements.append(val)

        return elements

    cpdef float decode_special_float(self):
        """Decode a float

        A special float is a float which is interpreted in
        some special way. The treatement is determined by
        the property's flags.

        +-------------------------+--------------------------------------+
        | Flag                    | Explanation                          |
        +=========================+======================================+
        | COORD                   | Treat the float or vector as a world |
        |                         | coordinate.                          |
        +-------------------------+--------------------------------------+
        | COORD_MP                | Like COORD but special handling for  |
        |                         | multi-player games.                  |
        +-------------------------+--------------------------------------+
        | COORD_MP_LOWPRECISION   | Like COORD_MP but the fractional     |
        |                         | component uses 3 bits instead of 5.  |
        +-------------------------+--------------------------------------+
        | COORD_MP_INTEGRAL       | Like COORD_MP but coordinates are    |
        |                         | rounded to integral boundaries.      |
        +-------------------------+--------------------------------------+
        | NOSCALE                 | Don't scale floating-point value to  |
        |                         | a range.                             |
        +-------------------------+--------------------------------------+
        | NORMAL                  | Treat vector as a normal.            |
        +-------------------------+--------------------------------------+
        | CELL_COORD              | Like COORD but has special encoding  |
        |                         | for cell coordinates which can't be  |
        |                         | negative.                            |
        +-------------------------+--------------------------------------+
        | CELL_COORD_LOWPRECISION | Like CELL_COORD but fractional part  |
        |                         | uses 3 bits instead of 5.            |
        +-------------------------+--------------------------------------+
        | CELL_COORD_INTEGRAL     | Like CELL_COORD but coordinates are  |
        |                         | rounded to integral boundaries.      |
        +-------------------------+--------------------------------------+
        """
        cdef float val = NAN
        cdef unsigned int f
        cdef unsigned int flags = self.flags

        if flags & PropFlags.SPROP_COORD:
            val = self.buf.read_bit_coord()
        elif flags & PropFlags.SPROP_COORD_MP:
            val = self.buf.read_bit_coord_mp(consts.CW_None)
        elif flags & PropFlags.SPROP_COORD_MP_LOWPRECISION:
            val = self.buf.read_bit_coord_mp(consts.CW_LowPrecision)
        elif flags & PropFlags.SPROP_COORD_MP_INTEGRAL:
            val = self.buf.read_bit_coord_mp(consts.CW_Integral)
        elif flags & PropFlags.SPROP_NOSCALE:
            f = self.buf.read_uint_bits(32)
            val = dereference(<float *>&f)
        elif flags & PropFlags.SPROP_NORMAL:
            val = self.buf.read_bit_normal()
        elif flags & PropFlags.SPROP_CELL_COORD:
            val = self.buf.read_bit_cell_coord(
                self.prop.num_bits, consts.CW_None
            )
        elif flags & PropFlags.SPROP_CELL_COORD_LOWPRECISION:
            val = self.buf.read_bit_cell_coord(
                self.prop.num_bits, consts.CW_LowPrecision
            )
        elif flags & PropFlags.SPROP_CELL_COORD_INTEGRAL:
            val = self.buf.read_bit_cell_coord(
                self.prop.num_bits, consts.CW_Integral
            )

        return val



import _pickle as pickle
from collections import MutableSequence

from demoparser import consts
from demoparser.entities import BaseEntity
from demoparser.entities import GameRules
from demoparser.entities import Player
from demoparser.entities import Team
from demoparser.entities import Weapon


class EntityList(MutableSequence):

    def __init__(self, parser):
        self.parser = parser
        self._entities = [None] * (1 << consts.MAX_EDICT_BITS)
        self.class_map = {
            'DT_BasePlayer': Player,
            'DT_Team': Team,
            'DT_WeaponCSBase': Weapon,
            'DT_CSGameRules': GameRules
        }
        self._cache = {}

    def __getitem__(self, index):
        return self._entities.__getitem__(index)

    def __setitem__(self, index, value):
        self._entities.__setitem__(index, value)

    def __len__(self):
        return len(self._entities)

    def __delitem__(self, index):
        self._entities.__delitem__(index)

    def insert(self, index, value):
        self._entities.insert(index, value)

    def new_entity(self, index, class_id, serial):
        """Create new entity.

        :returns: Created entity.
        """
        if self._entities[index]:
            self._entities[index] = None

        baseline = self.parser.instance_baselines[class_id]

        cls = BaseEntity
        # Find an entity class based on which tables are in its baseline.
        # Class IDs don't seem to be consistent across demo files so all
        # you can do is assume if an entity baseline has 'DT_Team' it must
        # be a Team.
        for table in baseline:
            if table in self.class_map:
                cls = self.class_map[table]
                break

        new_baseline = pickle.loads(pickle.dumps(baseline))
        assert baseline == new_baseline
        entity = cls(self.parser, index, class_id, serial, new_baseline)

        self._entities[index] = entity
        return entity

    def _get_by_class(self, cls):
        return [x for x in self._entities if isinstance(x, cls)]

    @property
    def players(self):
        """Get all Players in the entity list."""
        return self._get_by_class(Player)

    @property
    def teams(self):
        """Get all Teams in the entity list."""
        return self._get_by_class(Team)

    @property
    def weapons(self):
        """Get all Weapons in the entity list."""
        return self._get_by_class(Weapon)

    def get_by_user_id(self, user_id):
        users = self.parser.table_by_name('userinfo')['entries']

        for idx, user in enumerate(users):
            if getattr(user['user_data'], 'user_id', None) == user_id:
                return self._entities[idx + 1]

    def get_by_handle(self, handle):
        if not handle:
            return
        ent = self._entities[handle & consts.NETWORKED_EHANDLE_ENT_ENTRY_MASK]
        if ent is None or ent.serial != (handle >> consts.MAX_EDICT_BITS):
            return

        return ent

    def get_one(self, table):
        if table in self._cache:
            return self._cache[table]

        for e in self._entities:
            if e and table in e.props:
                self._cache[table] = e
                return e



# flake8: noqa
from demoparser.entities.base import BaseEntity
from demoparser.entities.game_rules import GameRules
from demoparser.entities.player import Player
from demoparser.entities.team import Team
from demoparser.entities.weapon import Weapon
from demoparser.entities.entity_list import EntityList



#!/usr/bin/env python

from setuptools import setup
from setuptools.extension import Extension

from Cython.Build import cythonize


extensions = [
    Extension(
        "demoparser.util",
        ["demoparser/util.pyx"]
    ),
    Extension(
        "demoparser.props",
        ["demoparser/props.pyx"],
    ),
    Extension(
        "demoparser.bitbuffer",
        ["demoparser/bitbuffer.pyx"]
    ),
    Extension(
        "demoparser.demofile",
        ["demoparser/demofile.pyx"]
    ),
]

setup(
    setup_requires=['pbr>=1.9', 'setuptools>=17.1'],
    pbr=True,
    ext_modules=cythonize(
        extensions, compiler_directives={
            "embedsignature": True,
            "linetrace": True,
            "language_level": 3
        }
    )
)



from demoparser.bitbuffer cimport Bitbuffer
from demoparser.props cimport Decoder
from demoparser.props cimport PropFlags
from demoparser.props cimport PropTypes

cpdef int read_field_index(Bitbuffer buf, int last_index, bint new_way):
    """Read index.

    This method determines the next index into the property
    list for a server class.

    :returns: Next index or -1 if no more indices
    """
    cdef int ret = 0
    cdef unsigned int val = 0

    if new_way and buf.read_bit():
        return last_index + 1

    if new_way and buf.read_bit():
        ret = buf.read_uint_bits(3)
    else:
        ret = buf.read_uint_bits(7)
        val = ret & (32 | 64)

        if val == 32:
            ret = (ret & ~96) | (buf.read_uint_bits(2) << 5)
            assert ret >= 32
        elif val == 64:
            ret = (ret & ~96) | (buf.read_uint_bits(4) << 5)
            assert ret >= 128
        elif val == 96:
            ret = (ret & ~96) | (buf.read_uint_bits(7) << 5)
            assert ret >= 512

    if ret == 0xfff:
        return -1

    return last_index + 1 + ret


cpdef list parse_entity_update(Bitbuffer buf, object server_class):
    """Parse entity updates.

    First a list of all property indices is generated. For each
    property referenced by those indices the property's value is
    decoded. The list of properties and their decoded values are
    collected and returned.

    :returns: List of updated properties
    """
    cdef bint new_way
    cdef int val = -1
    cdef Decoder decoder

    updated_props = []
    field_indices = []

    new_way = buf.read_bit()

    while True:
        val = read_field_index(buf, val, new_way)

        if val == -1:
            break

        field_indices.append(val)

    for index in field_indices:
        flattened_prop = server_class['props'][index]

        decoder = Decoder.__new__(Decoder, buf, flattened_prop)

        updated_props.append({
            'prop': flattened_prop,
            'value': decoder.decode()
        })

    return updated_props



MAX_CUSTOM_FILES = 4
MAX_EDICT_BITS = 11
MAX_PATH = 260
MAX_SPLITSCREEN_CLIENTS = 2
MAX_PLAYER_NAME_LENGTH = 128
MAX_USERDATA_BITS = 14
NUM_NETWORKED_EHANDLE_SERIAL_NUMBER_BITS = 10
SIGNED_GUID_LEN = 33
SUBSTRING_BITS = 5

CW_None = 0
CW_LowPrecision = 1
CW_Integral = 2

COORD_INTEGER_BITS = 14
COORD_FRACTIONAL_BITS = 5
COORD_DENOMINATOR = (1 << COORD_FRACTIONAL_BITS)
COORD_RESOLUTION = (1.0 / COORD_DENOMINATOR)

COORD_INTEGER_BITS_MP = 11
COORD_FRACTIONAL_BITS_MP_LOWPRECISION = 3
COORD_DENOMINATOR_LOWPRECISION = (1 << COORD_FRACTIONAL_BITS_MP_LOWPRECISION)
COORD_RESOLUTION_LOWPRECISION = (1.0 / COORD_DENOMINATOR_LOWPRECISION)

NORMAL_FRACTIONAL_BITS = 11
NORMAL_DENOMINATOR = (1 << NORMAL_FRACTIONAL_BITS) - 1
NORMAL_RESOLUTION = (1.0 / NORMAL_DENOMINATOR)

MAX_EDICT_BITS = 11
NETWORKED_EHANDLE_ENT_ENTRY_MASK = (1 << MAX_EDICT_BITS) - 1
NUM_NETWORKED_EHANDLE_SERIAL_NUMBER_BITS = 10
NUM_NETWORKED_EHANDLE_BITS = \
    MAX_EDICT_BITS + NUM_NETWORKED_EHANDLE_SERIAL_NUMBER_BITS
INVALID_NETWORKED_EHANDLE_VALUE = (1 << NUM_NETWORKED_EHANDLE_BITS) - 1
